@@ -2,8 +2,8 @@ context("portion.R")
 
 test_that("portions works", {
   # amox resistance in `septic_patients`
-  expect_equal(portion_R(septic_patients$amox), 0.6603, tolerance = 0.0001)
-  expect_equal(portion_I(septic_patients$amox), 0.0030, tolerance = 0.0001)
+  expect_equal(portion_R(septic_patients$amox), 0.662, tolerance = 0.0001)
+  expect_equal(portion_I(septic_patients$amox), 0.003, tolerance = 0.0001)
   expect_equal(1 - portion_R(septic_patients$amox) - portion_I(septic_patients$amox),
                portion_S(septic_patients$amox))
   expect_equal(portion_R(septic_patients$amox) + portion_I(septic_patients$amox),
@@ -11,12 +11,19 @@ test_that("portions works", {
   expect_equal(portion_S(septic_patients$amox) + portion_I(septic_patients$amox),
                portion_SI(septic_patients$amox))
 
-  # pita+genta susceptibility around 98.09%
-  expect_equal(suppressWarnings(rsi(septic_patients$pita,
+  expect_equal(septic_patients %>% portion_S(amcl),
+               0.6706853,
+               tolerance = 0.001)
+  expect_equal(septic_patients %>% portion_S(amcl, gent),
+               0.9202373,
+               tolerance = 0.001)
+
+  # amcl+genta susceptibility around 92.1%
+  expect_equal(suppressWarnings(rsi(septic_patients$amcl,
                                     septic_patients$gent,
                                     interpretation = "S")),
-               0.9535,
-               tolerance = 0.0001)
+               0.9202373,
+               tolerance = 0.000001)
 
   # percentages
   expect_equal(septic_patients %>%
@@ -28,7 +35,7 @@ test_that("portions works", {
                            total = n()) %>%
                  pull(n) %>%
                  sum(),
-               1404)
+               1409)
 
   # count of cases
   expect_equal(septic_patients %>%
@@ -40,31 +47,25 @@ test_that("portions works", {
                            combination_p = portion_S(cipr, gent, as_percent = TRUE),
                            combination_n = n_rsi(cipr, gent)) %>%
                  pull(combination_n),
-               c(202, 482, 201, 499))
+               c(202, 488, 201, 499))
 
   expect_warning(portion_R(as.character(septic_patients$amcl)))
   expect_warning(portion_S(as.character(septic_patients$amcl)))
   expect_warning(portion_S(as.character(septic_patients$amcl,
                                              septic_patients$gent)))
-  expect_equal(n_rsi(as.character(septic_patients$amcl,
-                                  septic_patients$gent)),
-               1570)
-
+  expect_warning(n_rsi(as.character(septic_patients$amcl,
+                                    septic_patients$gent)))
+  expect_equal(suppressWarnings(n_rsi(as.character(septic_patients$amcl,
+                                                   septic_patients$gent))),
+               1576)
 
   # check for errors
-  expect_error(portion_IR(septic_patients %>% select(amox, amcl)))
   expect_error(portion_IR("test", minimum = "test"))
   expect_error(portion_IR("test", as_percent = "test"))
-  expect_error(portion_I(septic_patients %>% select(amox, amcl)))
   expect_error(portion_I("test", minimum = "test"))
   expect_error(portion_I("test", as_percent = "test"))
   expect_error(portion_S("test", minimum = "test"))
   expect_error(portion_S("test", as_percent = "test"))
-  expect_error(portion_S(septic_patients %>% select(amox, amcl)))
-  expect_error(portion_S("R", septic_patients %>% select(amox, amcl)))
-  expect_error(n_rsi(septic_patients %>% select(amox, amcl)))
-  expect_error(n_rsi(septic_patients$amox, septic_patients %>% select(amox, amcl)))
-
 
   # check too low amount of isolates
   expect_identical(portion_R(septic_patients$amox, minimum = nrow(septic_patients) + 1),
@@ -83,15 +84,15 @@ test_that("portions works", {
 
 test_that("old rsi works", {
   # amox resistance in `septic_patients` should be around 66.33%
-  expect_equal(suppressWarnings(rsi(septic_patients$amox)), 0.6633, tolerance = 0.0001)
-  expect_equal(suppressWarnings(rsi(septic_patients$amox, interpretation = "S")), 1 - 0.6633, tolerance = 0.0001)
+  expect_equal(suppressWarnings(rsi(septic_patients$amox)), 0.665, tolerance = 0.0001)
+  expect_equal(suppressWarnings(rsi(septic_patients$amox, interpretation = "S")), 1 - 0.665, tolerance = 0.0001)
 
   # pita+genta susceptibility around 98.09%
   expect_equal(suppressWarnings(rsi(septic_patients$pita,
                                     septic_patients$gent,
                                     interpretation = "S",
                                     info = TRUE)),
-               0.9535,
+               0.9540412,
                tolerance = 0.0001)
 
   # count of cases
@@ -107,11 +108,11 @@ test_that("old rsi works", {
                                                                 as_percent = TRUE, warning = FALSE)),
                            combination_n = n_rsi(cipr, gent)) %>%
                  pull(combination_n),
-               c(202, 482, 201, 499))
+               c(202, 488, 201, 499))
 
   # portion_df
   expect_equal(
-    septic_patients %>% select(amox) %>% portion_df() %>% pull(Percentage),
+    septic_patients %>% select(amox) %>% portion_df() %>% pull(Value),
     c(septic_patients$amox %>% portion_S(),
       septic_patients$amox %>% portion_I(),
       septic_patients$amox %>% portion_R())
@@ -121,7 +122,7 @@ test_that("old rsi works", {
 
 test_that("prediction of rsi works", {
   amox_R <- septic_patients %>%
-    filter(bactid == "ESCCOL") %>%
+    filter(mo == "B_ESCHR_COL") %>%
     rsi_predict(col_ab = "amox",
                 col_date = "date",
                 minimum = 10,
@@ -130,38 +131,41 @@ test_that("prediction of rsi works", {
   # amox resistance will increase according to data set `septic_patients`
   expect_true(amox_R[3] < amox_R[20])
 
-  expect_output(rsi_predict(tbl = filter(septic_patients, bactid == "ESCCOL"),
+  expect_output(rsi_predict(tbl = filter(septic_patients, mo == "B_ESCHR_COL"),
                             model = "binomial",
                             col_ab = "amox",
                             col_date = "date",
                             info = TRUE))
-  expect_output(rsi_predict(tbl = filter(septic_patients, bactid == "ESCCOL"),
+  expect_output(rsi_predict(tbl = filter(septic_patients, mo == "B_ESCHR_COL"),
                             model = "loglin",
                             col_ab = "amox",
                             col_date = "date",
                             info = TRUE))
-  expect_output(rsi_predict(tbl = filter(septic_patients, bactid == "ESCCOL"),
+  expect_output(rsi_predict(tbl = filter(septic_patients, mo == "B_ESCHR_COL"),
                             model = "lin",
                             col_ab = "amox",
                             col_date = "date",
                             info = TRUE))
 
-  expect_error(rsi_predict(tbl = filter(septic_patients, bactid == "ESCCOL"),
+  expect_error(rsi_predict(tbl = filter(septic_patients, mo == "B_ESCHR_COL"),
                            model = "INVALID MODEL",
                            col_ab = "amox",
                            col_date = "date",
                            info = TRUE))
-  expect_error(rsi_predict(tbl = filter(septic_patients, bactid == "ESCCOL"),
+  expect_error(rsi_predict(tbl = filter(septic_patients, mo == "B_ESCHR_COL"),
                            col_ab = "NOT EXISTING COLUMN",
                            col_date = "date",
                            info = TRUE))
-  expect_error(rsi_predict(tbl = filter(septic_patients, bactid == "ESCCOL"),
+  expect_error(rsi_predict(tbl = filter(septic_patients, mo == "B_ESCHR_COL"),
                            col_ab = "amox",
                            col_date = "NOT EXISTING COLUMN",
                            info = TRUE))
   # almost all E. coli are mero S in the Netherlands :)
-  expect_error(resistance_predict(tbl = filter(septic_patients, bactid == "ESCCOL"),
+  expect_error(resistance_predict(tbl = filter(septic_patients, mo == "B_ESCHR_COL"),
                                   col_ab = "mero",
                                   col_date = "date",
                                   info = TRUE))
+
+  expect_error(portion_df(c("A", "B", "C")))
+  expect_error(portion_df(septic_patients[,"date"]))
 })
